#
# spec file for package python-npTDMS
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-npTDMS
Version:        1.9.0
Release:        1.2
Summary:        Python module for reading TDMS files produced by LabView
License:        LGPL-3.0-only
URL:            https://github.com/adamreeve/npTDMS
Source:         https://github.com/adamreeve/npTDMS/archive/%{version}.tar.gz#/npTDMS-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
NumPy based module for reading TDMS files produced by LabView.

%prep
%setup -q -n npTDMS-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/tdmsinfo
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# unpackaged dependency thermocouples_reference is needed just for this test
%pytest --ignore "nptdms/test/test_thermocouples.py"

%post
%python_install_alternative tdmsinfo

%postun
%python_uninstall_alternative tdmsinfo

%files %{python_files}
%doc README.rst
%license COPYING COPYING.LESSER
%python_alternative %{_bindir}/tdmsinfo
%{python_sitelib}/nptdms
%{python_sitelib}/npTDMS-%{version}*info

%changelog
* Tue Mar 26 2024 Markéta Machová <mmachova@suse.com>
- Update to 1.9.0
  * Implement __contains__ for TdmsFile and TdmsGroup
  * Allow using Arrow datatypes when converting to Pandas DataFrame
  * Raw timestamps support for writer and defragment
  * Fix reading truncated data when the next segment offset is set
  * Expose information about incomplete final segments
- Really run the tests
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Minor release that fixes the API documentation not being
    built correctly
- update to 1.7.0:
  * Ensure root and group objects required are written
- update to 1.6.2:
  * Fix deprecation warnings when installing
  * Handle invalid UTF-8 encoded strings
- update to 1.6.1:
  * Fixes numpy bool8 deprecation warning.
- update to 1.6.0:
  * Support writing tdms_index files and directly reading
    tdms_index files
  * Add TdmsWriter.defragment method for rewriting a TDMS file
  * Drop support for Python 2.7 and 3.6
- update to 1.5.0:
  * ## What's Changed
  * Support all remaining strain gauge configurations
  * Add option to specify the TDMS format version to write
  * Fix reading files with truncated metadata in the final
    segment
  * Support IPython auto-completion for group and channel names
- update to 1.4.0:
  * Improve performance reading data into numpy arrays
  * Fix getting channel time track when using raw timestamps
  * Fix numpy deprecation warnings
- update to 1.3.1:
  * Bug fix to handle when the first segment does not have
    kTocNewObjList set
- update to 1.3.0:
  * Handle segments containing data for a single string channel
    with the interleaved flag set
  * Improve handling of incomplete segment data
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.2.0:
  * Reduce memory usage when reading files in open mode
  * Support files that use DAQmx format metadata without having DAQmx raw data
  * Support different lengths of DAQmx buffers
  * Support strain scaling with a full bridge type I configuration
  * Support negative integer indexing in channels
  * Improve performance reading many small interleaved data chunks
  * Breaking change: Remove previously deprecated methods
  * Correct the TDMS type used when writing floating point data
  * Fix reading digital line scaler data with a non-zero offset
  * Adds support for reading raw timestamps with full precision
  * Fixes memory leaks caused by circular references
  * Fix for reading tdms_index files with padding after metadata
  * Add support for negative temperatures with RTD scaling
  * Use tdms_index files when available
  * Support indexing and slicing channels
  * Support streaming data chunks
  * Support iterating over files, groups and channels
  * Deprecates many methods than will now warn when used
  * Fixes inconsistent behaviour when exporting to Pandas dataframes
- Do not build for Python 3.6, due to no NumPy.
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Nov 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
